@@ -39,6 +39,9 @@ class RestClient(object):
 
     TYPE = "json"
 
+    # The version of the API this client implements
+    api_version = None
+
     LOG = logging.getLogger(__name__)
 
     def __init__(self, auth_provider, service, region,
@@ -54,8 +57,6 @@ class RestClient(object):
         self.build_timeout = build_timeout
         self.trace_requests = trace_requests
 
-        # The version of the API this client implements
-        self.api_version = None
         self._skip_path = False
         self.general_header_lc = set(('cache-control', 'connection',
                                       'date', 'pragma', 'trailer',
@@ -423,9 +424,12 @@ class RestClient(object):
         else:
             raise exceptions.InvalidContentType(str(resp.status))
 
-        if resp.status == 401 or resp.status == 403:
+        if resp.status == 401:
             raise exceptions.Unauthorized(resp_body)
 
+        if resp.status == 403:
+            raise exceptions.Forbidden(resp_body)
+
         if resp.status == 404:
             raise exceptions.NotFound(resp_body)
 
